@@ -2,13 +2,14 @@
  *
  * NAGIOS.C - Core Program Code For Nagios
  *
- * Program: Nagios
- * Version: 3.0.6
+ * Program: Nagios Core
+ * Version: 3.2.0
  * License: GPL
- * Copyright (c) 1999-2007 Ethan Galstad (http://www.nagios.org)
+ * Copyright (c) 2009 Nagios Core Development Team and Community Contributors
+ * Copyright (c) 1999-2009 Ethan Galstad
  *
  * First Written:   01-28-1999 (start of development)
- * Last Modified:   12-01-2008
+ * Last Modified:   08-12-2009
  *
  * Description:
  *
@@ -130,6 +131,13 @@ int             auto_rescheduling_window=DEFAULT_AUTO_RESCHEDULING_WINDOW;
 
 int             additional_freshness_latency=DEFAULT_ADDITIONAL_FRESHNESS_LATENCY;
 
+int             check_for_updates=DEFAULT_CHECK_FOR_UPDATES;
+int             bare_update_check=DEFAULT_BARE_UPDATE_CHECK;
+time_t          last_update_check=0L;
+int             update_available=FALSE;
+char            *last_program_version=NULL;
+char            *new_program_version=NULL;
+
 time_t          last_command_check=0L;
 time_t          last_command_status_update=0L;
 time_t          last_log_rotation=0L;
@@ -376,10 +384,12 @@ int main(int argc, char **argv){
 #endif
 
 	if(daemon_mode==FALSE){
-		printf("\nNagios %s\n",PROGRAM_VERSION);
-		printf("Copyright (c) 1999-2008 Ethan Galstad (http://www.nagios.org)\n");
+		printf("\nNagios Core %s\n",PROGRAM_VERSION);
+		printf("Copyright (c) 2009 Nagios Core Development Team and Community Contributors\n");
+		printf("Copyright (c) 1999-2009 Ethan Galstad\n");
 		printf("Last Modified: %s\n",PROGRAM_MODIFICATION_DATE);
 		printf("License: GPL\n\n");
+		printf("Website: http://www.nagios.org\n");
 	        }
 
 	/* just display the license */
@@ -469,18 +479,28 @@ int main(int argc, char **argv){
 		/* reset program variables */
 		reset_variables();
 
-		printf("Reading configuration data...\n\n");
+		printf("Reading configuration data...\n");
 
 		/* read in the configuration files (main config file, resource and object config files) */
 		if((result=read_main_config_file(config_file))==OK){
 
+			printf("   Read main config file okay...\n");
+
 			/* drop privileges */
 			if((result=drop_privileges(nagios_user,nagios_group))==ERROR)
-				printf("Failed to drop privileges.  Aborting.");
-			else
+				printf("   Failed to drop privileges.  Aborting.");
+			else{
 				/* read object config files */
-				result=read_all_object_data(config_file);
+				if((result=read_all_object_data(config_file))==OK)
+					printf("   Read object config files okay...\n");
+				else
+					printf("   Error processing object config files!\n");
+				}
 		        }
+		else
+			printf("   Error processing main config file!\n\n");
+
+		printf("\n");
 
 		/* there was a problem reading the config files */
 		if(result!=OK){
@@ -586,6 +606,21 @@ int main(int argc, char **argv){
 				}
 		        }
 
+#undef TEST_TIMEPERIODS
+#ifdef TEST_TIMEPERIODS
+		/* DO SOME TIMEPERIOD TESTING - ADDED 08/11/2009 */
+		time_t now, pref_time, valid_time;
+		timeperiod *tp;
+		tp=find_timeperiod("247_exclusion");
+		time(&now);
+		pref_time=now;
+		get_next_valid_time(pref_time,&valid_time,tp);
+		printf("=====\n");
+		printf("CURRENT:   %lu = %s",(unsigned long)now,ctime(&now));
+		printf("PREFERRED: %lu = %s",(unsigned long)pref_time,ctime(&pref_time));
+		printf("NEXT:      %lu = %s",(unsigned long)valid_time,ctime(&valid_time));
+		printf("=====\n");
+#endif
 
 		/* clean up after ourselves */
 		cleanup();
@@ -727,7 +762,19 @@ int main(int argc, char **argv){
 			/* enter daemon mode (unless we're restarting...) */
 			if(daemon_mode==TRUE && sigrestart==FALSE){
 
-				daemon_init();
+				result=daemon_init();
+
+				/* we had an error daemonizing, so bail... */
+				if(result==ERROR){
+					logit(NSLOG_PROCESS_INFO | NSLOG_RUNTIME_ERROR,TRUE,"Bailing out due to failure to daemonize. (PID=%d)",(int)getpid());
+
+#ifdef USE_EVENT_BROKER
+					/* send program data to broker */
+					broker_program_state(NEBTYPE_PROCESS_SHUTDOWN,NEBFLAG_PROCESS_INITIATED,NEBATTR_SHUTDOWN_ABNORMAL,NULL);
+#endif
+					cleanup();
+					exit(ERROR);
+					}
 
 				asprintf(&buffer,"Finished daemonizing... (New PID=%d)\n",(int)getpid());
 				write_to_all_logs(buffer,NSLOG_PROCESS_INFO);
@@ -774,6 +821,9 @@ int main(int argc, char **argv){
 			/* initialize check statistics */
 			init_check_stats();
 
+			/* check for updates */
+			check_for_nagios_updates(FALSE,TRUE);
+
 			/* update all status data (with retained information) */
 			update_all_status_data();
 
