@@ -2,8 +2,9 @@
  *
  * XSDDEFAULT.C - Default external status data input routines for Nagios
  *
- * Copyright (c) 2000-2008 Ethan Galstad (egalstad@nagios.org)
- * Last Modified: 11-30-2008
+ * Copyright (c) 2009 Nagios Core Development Team and Community Contributors
+ * Copyright (c) 2000-2009 Ethan Galstad (egalstad@nagios.org)
+ * Last Modified: 07-31-2009
  *
  * License:
  *
@@ -93,6 +94,12 @@ extern int process_performance_data;
 extern int aggregate_status_updates;
 extern int check_external_commands;
 
+extern time_t         last_update_check;
+extern char           *last_program_version;
+extern int            update_available;
+extern char           *last_program_version;
+extern char           *new_program_version;
+
 extern int external_command_buffer_slots;
 extern circular_buffer external_command_buffer;
 
@@ -403,6 +410,10 @@ int xsddefault_save_status_data(void){
 	fprintf(fp,"info {\n");
 	fprintf(fp,"\tcreated=%lu\n",current_time);
 	fprintf(fp,"\tversion=%s\n",PROGRAM_VERSION);
+	fprintf(fp,"\tlast_update_check=%lu\n",last_update_check);
+	fprintf(fp,"\tupdate_available=%d\n",update_available);
+	fprintf(fp,"\tlast_version=%s\n",(last_program_version==NULL)?"":last_program_version);
+	fprintf(fp,"\tnew_version=%s\n",(new_program_version==NULL)?"":new_program_version);
 	fprintf(fp,"\t}\n\n");
 
 	/* save program status data */
@@ -485,8 +496,6 @@ int xsddefault_save_status_data(void){
 		fprintf(fp,"\tcheck_options=%d\n",temp_host->check_options);
 		fprintf(fp,"\tcurrent_attempt=%d\n",temp_host->current_attempt);
 		fprintf(fp,"\tmax_attempts=%d\n",temp_host->max_attempts);
-		fprintf(fp,"\tcurrent_event_id=%lu\n",temp_host->current_event_id);
-		fprintf(fp,"\tlast_event_id=%lu\n",temp_host->last_event_id);
 		fprintf(fp,"\tstate_type=%d\n",temp_host->state_type);
 		fprintf(fp,"\tlast_state_change=%lu\n",temp_host->last_state_change);
 		fprintf(fp,"\tlast_hard_state_change=%lu\n",temp_host->last_hard_state_change);
@@ -554,8 +563,6 @@ int xsddefault_save_status_data(void){
 		fprintf(fp,"\tlast_problem_id=%lu\n",temp_service->last_problem_id);
 		fprintf(fp,"\tcurrent_attempt=%d\n",temp_service->current_attempt);
 		fprintf(fp,"\tmax_attempts=%d\n",temp_service->max_attempts);
-		fprintf(fp,"\tcurrent_event_id=%lu\n",temp_service->current_event_id);
-		fprintf(fp,"\tlast_event_id=%lu\n",temp_service->last_event_id);
 		fprintf(fp,"\tstate_type=%d\n",temp_service->state_type);
 		fprintf(fp,"\tlast_state_change=%lu\n",temp_service->last_state_change);
 		fprintf(fp,"\tlast_hard_state_change=%lu\n",temp_service->last_hard_state_change);
@@ -674,9 +681,15 @@ int xsddefault_save_status_data(void){
 	/* reset file permissions */
 	fchmod(fd,S_IRUSR | S_IWUSR | S_IRGRP | S_IWGRP | S_IROTH);
 
+	/* flush the file to disk */
+	fflush(fp);
+
 	/* close the temp file */
 	result=fclose(fp);
 
+	/* fsync the file so that it is completely written out before moving it */
+	fsync(fd);
+
 	/* save/close was successful */
 	if(result==0){
 
